Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(125)

Unified Diff: content/public/common/platform_notification_data.h

Issue 1855443002: Implement receiving side of web notification inline replies (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Added test and removed unnecessary code. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/platform_notification_data.h
diff --git a/content/public/common/platform_notification_data.h b/content/public/common/platform_notification_data.h
index b96cd802f8576639c0262e91d1bb540da7466602..8c5243001e7c8131708ecaf45de2f43c1b3f7aa4 100644
--- a/content/public/common/platform_notification_data.h
+++ b/content/public/common/platform_notification_data.h
@@ -10,6 +10,7 @@
#include <string>
#include <vector>
+#include "base/strings/nullable_string16.h"
#include "base/strings/string16.h"
#include "base/time/time.h"
#include "content/common/content_export.h"
@@ -17,11 +18,20 @@
namespace content {
-// A notification action (button); corresponds to Blink WebNotificationAction.
+enum CONTENT_EXPORT PlatformNotificationActionType {
+ PLATFORM_NOTIFICATION_ACTION_TYPE_BUTTON = 0,
+ PLATFORM_NOTIFICATION_ACTION_TYPE_TEXT,
+};
+
+// A notification action (button or text input); corresponds to Blink
+// WebNotificationAction.
struct CONTENT_EXPORT PlatformNotificationAction {
PlatformNotificationAction();
~PlatformNotificationAction();
+ // Type of the action (button or text input).
+ PlatformNotificationActionType type;
+
// Action name that the author can use to distinguish them.
std::string action;
@@ -30,6 +40,10 @@ struct CONTENT_EXPORT PlatformNotificationAction {
// URL of the icon for the button. May be empty if no url was specified.
GURL icon;
+
+ // Optional text to use as placeholder for text inputs. May be null if it was
+ // not specified.
+ base::NullableString16 placeholder;
};
// Structure representing the information associated with a Web Notification.

Powered by Google App Engine
This is Rietveld 408576698